PENEPMA
=======

Input
-----

.. automodule:: pypenelopetools.penepma.input
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:

Results
-------

.. automodule:: pypenelopetools.penepma.results
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:

Keywords
--------

.. automodule:: pypenelopetools.penepma.keywords
    :members:
    :show-inheritance: